@@ -2,8 +2,14 @@
 
 import ctypes as c
 import os
+import sys
+
+if sys.platform.startswith('darwin'):
+    _ = c.CDLL(os.path.join(os.path.dirname(__file__), "gmp.dylib"))
+
+if sys.platform.startswith('win32') or sys.platform.startswith('cygwin'):
+    _ = c.CDLL(os.path.join(os.path.dirname(__file__), "gmp.dll"))
 
-_ = c.CDLL(os.path.join(os.path.dirname(__file__), "gmp.dylib"))
 
 _.pfib.argtypes = (c.c_ulonglong,)
 
@@ -38,7 +44,7 @@ def fibonacci(term: int, precision: int = 1000) -> int:
     if not (isinstance(term, int) and term >= 0):
         raise ValueError("'term' has to be bigger than 0 and 'int'.")
 
-    return int(_.fibonacci(term).decode('utf-8'))
+    return int(_.fibonacci(term, precision).decode('utf-8'))
 
 
 if __name__ == "__main__":
